@@ -4,6 +4,8 @@ namespace Wallabag\ApiBundle\Entity;
 
 use Doctrine\ORM\Mapping as ORM;
 use FOS\OAuthServerBundle\Entity\RefreshToken as BaseRefreshToken;
+use FOS\OAuthServerBundle\Model\ClientInterface;
+use FOS\UserBundle\Model\UserInterface;
 
 /**
  * @ORM\Table("oauth2_refresh_tokens")
@@ -37,12 +39,16 @@ class RefreshToken extends BaseRefreshToken
     /**
      * @ORM\ManyToOne(targetEntity="Client", inversedBy="refreshTokens")
      * @ORM\JoinColumn(nullable=false)
+     *
+     * @var ClientInterface
      */
     protected $client;
 
     /**
      * @ORM\ManyToOne(targetEntity="Wallabag\UserBundle\Entity\User")
      * @ORM\JoinColumn(name="user_id", referencedColumnName="id", onDelete="CASCADE")
+     *
+     * @var UserInterface
      */
     protected $user;
 }
