@@ -226,21 +226,6 @@ class EntryRepository extends ServiceEntityRepository
             ;
     }
 
-    /**
-     * Retrieve entries with annotations count for a user.
-     *
-     * @param int $userId
-     *
-     * @return QueryBuilder
-     */
-    public function getCountBuilderForAnnotationsByUser($userId)
-    {
-        return $this
-            ->getQueryBuilderByUser($userId)
-            ->innerJoin('e.annotations', 'a')
-            ;
-    }
-
     /**
      * Retrieve untagged entries for a user.
      *
@@ -281,14 +266,15 @@ class EntryRepository extends ServiceEntityRepository
      * @param string $order
      * @param int    $since
      * @param string $tags
-     * @param string $detail     'metadata' or 'full'. Include content field if 'full'
+     * @param string $detail         'metadata' or 'full'. Include content field if 'full'
      * @param string $domainName
+     * @param bool   $hasAnnotations
      *
      * @todo Breaking change: replace default detail=full by detail=metadata in a future version
      *
      * @return Pagerfanta
      */
-    public function findEntries($userId, $isArchived = null, $isStarred = null, $isPublic = null, $sort = 'created', $order = 'asc', $since = 0, $tags = '', $detail = 'full', $domainName = '')
+    public function findEntries($userId, $isArchived = null, $isStarred = null, $isPublic = null, $sort = 'created', $order = 'asc', $since = 0, $tags = '', $detail = 'full', $domainName = '', $hasAnnotations = null)
     {
         if (!\in_array(strtolower($detail), ['full', 'metadata'], true)) {
             throw new \Exception('Detail "' . $detail . '" parameter is wrong, allowed: full or metadata');
@@ -347,6 +333,16 @@ class EntryRepository extends ServiceEntityRepository
             $qb->andWhere('e.domainName = :domainName')->setParameter('domainName', $domainName);
         }
 
+        if (null !== $hasAnnotations) {
+            if ($hasAnnotations) {
+                $qb->leftJoin('e.annotations', 'a')
+                   ->andWhere('a.id IS NOT NULL');
+            } else {
+                $qb->leftJoin('e.annotations', 'a')
+                   ->andWhere('a.id IS NULL');
+            }
+        }
+
         if (!\in_array(strtolower($order), ['asc', 'desc'], true)) {
             throw new \Exception('Order "' . $order . '" parameter is wrong, allowed: asc or desc');
         }
